"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const path_1 = require("path");
/**
 * Returns the passed template string with any given replacement variables replaced with
 * their respective value.
 * @param templateContent {string}
 * @param replacements {string[]}
 * @returns {string}
 */
function getFilledTemplate(templateContent, replacements) {
    return replacements.reduce((acc, [name, replacement]) => acc.replace(new RegExp(`\\$${name}\\$`, 'g'), replacement), templateContent);
}
exports.getFilledTemplate = getFilledTemplate;
/**
 * Creates the directory structure and files for the TBA game based on the
 * passed configuration options.
 * @param options {CreateOptions}
 */
function createGame(options) {
    const { title, about, dirName, template } = options;
    const replacements = [['title', title], ['about', about], ['dirName', dirName], ['version', '*']];
    const targetPath = path_1.resolve(process.cwd(), dirName);
    if (fs_1.existsSync(targetPath)) {
        console.error('Target folder already exists, enter a new folder name');
        return 1;
    }
    fs_1.mkdirSync(targetPath);
    const templatePath = path_1.resolve(__dirname, 'templates', template);
    const templateFileNames = fs_1.readdirSync(templatePath).filter((fileName) => fileName.slice(-4) === '.txt');
    templateFileNames.forEach((templateFileName) => {
        const templateFilePath = path_1.resolve(templatePath, templateFileName);
        const templateContent = fs_1.readFileSync(templateFilePath).toString();
        const outFileName = templateFileName.slice(0, -4);
        const outFilePath = path_1.resolve(targetPath, outFileName);
        const outFileContent = getFilledTemplate(templateContent, replacements);
        fs_1.writeFileSync(outFilePath, outFileContent);
    });
    console.log(`Created ${dirName} folder successfully. Change to that folder and run npm install.`);
    return 0;
}
exports.default = createGame;
//# sourceMappingURL=createGame.js.map