#!/usr/bin/env node
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const inquirer = __importStar(require("inquirer"));
const createGame_1 = __importDefault(require("./createGame"));
const trim = (str = '') => str.trim();
const getKebabCase = (str = '') => trim(str)
    .replace(/ /g, '-')
    .toLowerCase();
exports.questions = [
    {
        name: 'title',
        message: 'Enter your game title',
        type: 'input',
        validate: (value) => {
            if (!trim(value)) {
                return 'A game title is required';
            }
            return true;
        }
    },
    {
        name: 'about',
        message: 'Enter a description (optional)',
        type: 'input'
    },
    {
        name: 'dirName',
        message: 'Enter a name to use for the game folder',
        type: 'input',
        default: ({ title }) => getKebabCase(title),
        validate: (value) => {
            if (!trim(value)) {
                return 'A folder name is required';
            }
            if (trim(value).includes(' ')) {
                return 'Please use a folder name without spaces';
            }
            return true;
        }
    }
];
function runPrompt() {
    return __awaiter(this, void 0, void 0, function* () {
        console.log('Welcome to create-tba-game. This program will ' +
            'create the basic setup required to start working ' +
            'on your very own Text-Based Adventure game!\n' +
            'You will be asked a few questions about your ' +
            'desired game.\n');
        const { title, about, dirName } = yield inquirer.prompt(exports.questions);
        const options = {
            title: trim(title),
            about: trim(about),
            dirName: getKebabCase(dirName),
            template: 'basic'
        };
        const exitCode = createGame_1.default(options);
        process.exit(exitCode);
    });
}
exports.default = runPrompt;
/* istanbul ignore if */
if (process.env.NODE_ENV !== 'test') {
    runPrompt();
}
//# sourceMappingURL=index.js.map